@@ -3,6 +3,8 @@ import os
 os.system("")
 
 def CreateFile(name, ifexists = False):
+    name = str(name)
+
     f = None
     if ifexists:
         if not os.path.exists(name):
@@ -12,6 +14,8 @@ def CreateFile(name, ifexists = False):
     return f
 
 def DeleteFile(name):
+    name = str(name)
+
     # os.remove(name)
     if os.path.exists(name):
         os.remove(name)
@@ -19,32 +23,47 @@ def DeleteFile(name):
         print("\033[91m" + "The file does not exist" + "\033[0m")
     
 def ReadFile(name):
+    name = str(name)
+
     f = open(name, 'r')
     contents = f.read()
     return contents
 
 def ReadFileLines(name):
+    name = str(name)
+
     f = open(name, 'r')
     contents = f.readlines()
     return contents
 
 def ReadFileLine(name, line):
+    name = str(name)
+    line = int(line)
+
     f = open(name, 'r')
     lines = f.readlines()
     line = lines[line - 1]
     return line
 
 def WriteFile(name, text):
+    name = str(name)
+    text = str(text)
+
     f = open(name, 'w')
     f.write(text)
     return f
     
 def AppendFile(name, text):
+    name = str(name)
+    text = str(text)
+
     f = open(name, 'a')
     f.write(text)
     return f
     
 def CheckFileExists(name):
+    name = str(name)
+
     exists = os.path.exists(name)
     return exists
 
